import unittest
from noid.pynoid import *
import re

class PynoidTests(unittest.TestCase):
    
    def setUp(self):
        pass

    def tearDown(self):
        pass

    def test_naa_append(self):
        noid = mint(naa='abc')
        self.assertTrue(noid.startswith('abc/'))

    def test_scheme_append(self):
        schemes = ['doi:', 'ark:/', 'http://']
        for scheme in schemes:
            noid = mint(scheme=scheme)
            self.assertTrue(noid.startswith(scheme))
    
    def test_mint_short_term(self):
        noid = mint()
        self.assertTrue(noid.startswith(SHORT))

    def test_mint_ns(self):
        ns = range(10)
        for n in ns:
            self.assertEqual(mint('d', n), DIGIT[n])
        ns = range(29)
        for n in ns:
            self.assertEqual(mint('e', n), XDIGIT[n])

    def test_namespace_overflow(self):
        self.assertRaises(NamespaceError, mint, template='d', n=10)
        self.assertRaises(NamespaceError, mint, template='e', n=29)

    def test_mint_z_rollover(self):
        self.assertEqual(mint('zd', 10), '10')        
        self.assertEqual(mint('ze', 29), '10')

    def test_validate_valid(self):
        valid = 'test31wqw0wsr'
        validScheme = 'ark:/test31wqw0wsr'
        self.assertTrue(validate(valid))
        self.assertTrue(validate(validScheme))

    def test_validate_invalid(self):
        invalid = 'test31qww0wsr'
        invalidScheme = 'ark:/test31qww0wsr'
        self.assertRaises(ValidationError, validate, invalid)
        self.assertRaises(ValidationError, validate, invalidScheme)

    def test_checkdigit(self):
        self.assertEqual(mint('eek', 100), '3f0')
        self.assertRaises(ValidationError, validate, 'f30')


if __name__ == '__main__':
    unittest.main()
        



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="noid-mint",
    version="0.0.3",
    author="Yinlin Chen, Tingting Jiang, Lee Hunter, Jim Tuttle",
    author_email="ylchen@vt.edu, virjtt03@vt.edu, whunter@vt.edu, jjt@vt.edu",
    description="Mint NOID",
    license="MIT",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/vt-digital-libraries-platform/NOID-mint",
    scripts=['bin/noid'],
    packages=setuptools.find_packages(),
    install_requires=[
        'pyyaml'
    ],
    classifiers=[
        "Programming Language :: Python :: 3.6",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
